@@ -1,11 +1,6 @@
 use MooseX::Declare;
 
 role Gitalist::Git::CollectionOfRepositories::Role::Context {
-    requires qw/
-        implementation_class
-        ACCEPT_CONTEXT
-    /;
-
     method implementation_class {
         $self->meta->name
     }
